==> telepathy-glib-0.19.0.tar.gz: telepathy-glib-0.19.0/telepathy-glib/telepathy-glib-dbus.h <==
/*
 * telepathy-glib-dbus.h - meta-header for all generated code
 *
 * Copyright © 2009-2012 Collabora Ltd. <http://www.collabora.co.uk/>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

#ifndef TELEPATHY_GLIB_DBUS_H_INCLUDED
#define TELEPATHY_GLIB_DBUS_H_INCLUDED
#define _TP_IN_META_HEADER

#include <telepathy-glib/telepathy-glib.h>

/* common */
#include <telepathy-glib/gtypes.h>
#include <telepathy-glib/interfaces.h>

/* client-side */
#include <telepathy-glib/_gen/tp-cli-account.h>
#include <telepathy-glib/_gen/tp-cli-account-manager.h>
#include <telepathy-glib/_gen/tp-cli-call-content.h>
#include <telepathy-glib/_gen/tp-cli-call-content-media-description.h>
#include <telepathy-glib/_gen/tp-cli-call-stream-endpoint.h>
#include <telepathy-glib/_gen/tp-cli-call-stream.h>
#include <telepathy-glib/_gen/tp-cli-channel-dispatcher.h>
#include <telepathy-glib/_gen/tp-cli-channel-dispatch-operation.h>
#include <telepathy-glib/_gen/tp-cli-channel.h>
#include <telepathy-glib/_gen/tp-cli-channel-request.h>
#include <telepathy-glib/_gen/tp-cli-client.h>
#include <telepathy-glib/_gen/tp-cli-connection.h>
#include <telepathy-glib/_gen/tp-cli-connection-manager.h>
#include <telepathy-glib/_gen/tp-cli-dbus-daemon.h>
#include <telepathy-glib/_gen/tp-cli-debug.h>
#include <telepathy-glib/_gen/tp-cli-generic.h>
#include <telepathy-glib/_gen/tp-cli-media-session-handler.h>
#include <telepathy-glib/_gen/tp-cli-media-stream-handler.h>
#include <telepathy-glib/_gen/tp-cli-protocol.h>

/* service-side */
#include <telepathy-glib/svc-account.h>
#include <telepathy-glib/svc-account-manager.h>
#include <telepathy-glib/svc-call.h>
#include <telepathy-glib/svc-channel-dispatcher.h>
#include <telepathy-glib/svc-channel-dispatch-operation.h>
#include <telepathy-glib/svc-channel.h>
#include <telepathy-glib/svc-channel-request.h>
#include <telepathy-glib/svc-client.h>
#include <telepathy-glib/svc-connection.h>
#include <telepathy-glib/svc-connection-manager.h>
#include <telepathy-glib/svc-debug.h>
#include <telepathy-glib/svc-generic.h>
#include <telepathy-glib/svc-media-interfaces.h>
#include <telepathy-glib/svc-properties-interface.h>
#include <telepathy-glib/svc-protocol.h>
#include <telepathy-glib/svc-tls.h>

#undef _TP_IN_META_HEADER
#endif

==> telepathy-glib-0.99.11.tar.gz: telepathy-glib-0.99.11/telepathy-glib/telepathy-glib-dbus.h <==
/*
 * telepathy-glib-dbus.h - meta-header for all generated code
 *
 * Copyright © 2009-2012 Collabora Ltd. <http://www.collabora.co.uk/>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

#ifndef __TP_GLIB_DBUS_H__
#define __TP_GLIB_DBUS_H__

#include <telepathy-glib/telepathy-glib.h>

#define _TP_GLIB_DBUS_H_INSIDE

/* utilities for the dbus-glib type system */
#include <telepathy-glib/asv.h>
#include <telepathy-glib/sliced-gvalue.h>
#include <telepathy-glib/value-array.h>

/* common */
#include <telepathy-glib/gnio-util.h>
#include <telepathy-glib/gtypes.h>
#include <telepathy-glib/interfaces.h>

/* client-side */
#include <telepathy-glib/cli-proxy.h>
#include <telepathy-glib/_gen/tp-cli-account.h>
#include <telepathy-glib/_gen/tp-cli-account-manager.h>
#include <telepathy-glib/_gen/tp-cli-call-content.h>
#include <telepathy-glib/_gen/tp-cli-call-content-media-description.h>
#include <telepathy-glib/_gen/tp-cli-call-stream-endpoint.h>
#include <telepathy-glib/_gen/tp-cli-call-stream.h>
#include <telepathy-glib/_gen/tp-cli-channel-dispatcher.h>
#include <telepathy-glib/_gen/tp-cli-channel-dispatch-operation.h>
#include <telepathy-glib/_gen/tp-cli-channel.h>
#include <telepathy-glib/_gen/tp-cli-channel-request.h>
#include <telepathy-glib/_gen/tp-cli-client.h>
#include <telepathy-glib/_gen/tp-cli-connection.h>
#include <telepathy-glib/_gen/tp-cli-connection-manager.h>
#include <telepathy-glib/_gen/tp-cli-debug.h>
#include <telepathy-glib/_gen/tp-cli-generic.h>
#include <telepathy-glib/_gen/tp-cli-protocol.h>
#include <telepathy-glib/_gen/tp-cli-logger.h>

/* service-side */
#include <telepathy-glib/dbus-properties-mixin.h>
#include <telepathy-glib/svc-account.h>
#include <telepathy-glib/svc-account-manager.h>
#include <telepathy-glib/svc-call.h>
#include <telepathy-glib/svc-channel-dispatcher.h>
#include <telepathy-glib/svc-channel-dispatch-operation.h>
#include <telepathy-glib/svc-channel.h>
#include <telepathy-glib/svc-channel-request.h>
#include <telepathy-glib/svc-client.h>
#include <telepathy-glib/svc-connection.h>
#include <telepathy-glib/svc-connection-manager.h>
#include <telepathy-glib/svc-debug.h>
#include <telepathy-glib/svc-generic.h>
#include <telepathy-glib/svc-interface.h>
#include <telepathy-glib/svc-properties-interface.h>
#include <telepathy-glib/svc-protocol.h>
#include <telepathy-glib/svc-tls.h>
#include <telepathy-glib/svc-logger.h>

#undef _TP_GLIB_DBUS_H_INSIDE

#endif /* __TP_GLIB_DBUS_H__ */
